# Generated by Django 4.0.5 on 2022-06-07 19:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dynfilters', '0003_alter_dynamicfilterexpr_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dynamicfilterexpr',
            name='is_global',
            field=models.BooleanField(db_index=True, default=False),
        ),
        migrations.AlterField(
            model_name='dynamicfilterexpr',
            name='model',
            field=models.CharField(db_index=True, max_length=64),
        ),
    ]
