# Generated by Django 4.0.5 on 2022-06-02 17:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dynfilters', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dynamicfilterexpr',
            name='model',
            field=models.CharField(default='test', max_length=64),
            preserve_default=False,
        ),
    ]
